W

Struct W 

pub struct W<REG: RegisterSpec + ?Sized> { /* private fields */ }
Register writer.

Used as an argument to the closures in the write and modify methods of the register.

Implementations

Source

impl<REG: RegisterSpec> W<REG>

pub unsafe fn bits(&mut self, bits: REG::Ux) -> &mut Self

Writes raw bits to the register.

Safety

Read datasheet or reference manual to find what values are allowed to pass.